from typing import Any

from braintree.configuration import Configuration as Configuration

class WebhookTesting:
    @staticmethod
    def sample_notification(kind, id, source_merchant_id: Any | None = ...): ...
