from typing import Any

from braintree.exceptions.configuration_error import ConfigurationError as ConfigurationError

class Environment:
    __name__: Any
    is_ssl: Any
    ssl_certificate: Any
    def __init__(
        self, name, server, port, auth_url, is_ssl, ssl_certificate, graphql_server: str = ..., graphql_port: str = ...
    ) -> None: ...
    @property
    def base_url(self): ...
    @property
    def port(self): ...
    @property
    def auth_url(self): ...
    @property
    def protocol(self): ...
    @property
    def server(self): ...
    @property
    def server_and_port(self): ...
    @property
    def graphql_server(self): ...
    @property
    def graphql_port(self): ...
    @property
    def graphql_server_and_port(self): ...
    @staticmethod
    def parse_environment(environment): ...
    @staticmethod
    def braintree_root(): ...
